==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/FirewallRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs.builder
import com.pulumi.azurenative.servicelinker.kotlin.enums.AllowType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Target service's firewall rules. to allow connections from source service.
 * @property azureServices Allow Azure services to access the target service if true.
 * @property callerClientIP Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
 * @property ipRanges This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
 */
public data class FirewallRulesArgs(
    public val azureServices: Output<Either<String, AllowType>>? = null,
    public val callerClientIP: Output<Either<String, AllowType>>? = null,
    public val ipRanges: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs =
        com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs.builder()
            .azureServices(
                azureServices?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .callerClientIP(
                callerClientIP?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipRanges(ipRanges?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FirewallRulesArgs].
 */
@PulumiTagMarker
public class FirewallRulesArgsBuilder internal constructor() {
    private var azureServices: Output<Either<String, AllowType>>? = null

    private var callerClientIP: Output<Either<String, AllowType>>? = null

    private var ipRanges: Output<List<String>>? = null

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("snukeaiphtsfspaa")
    public suspend fun azureServices(`value`: Output<Either<String, AllowType>>) {
        this.azureServices = value
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("nhxknktxviwwddms")
    public suspend fun callerClientIP(`value`: Output<Either<String, AllowType>>) {
        this.callerClientIP = value
    }

    /**
     * @param value This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("drbinkiaskeyubdn")
    public suspend fun ipRanges(`value`: Output<List<String>>) {
        this.ipRanges = value
    }

    @JvmName("ldknvuiwkhohqimg")
    public suspend fun ipRanges(vararg values: Output<String>) {
        this.ipRanges = Output.all(values.asList())
    }

    /**
     * @param values This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("llnxctjrkfjrmont")
    public suspend fun ipRanges(values: List<Output<String>>) {
        this.ipRanges = Output.all(values)
    }

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("mkkctqhcivgkxurm")
    public suspend fun azureServices(`value`: Either<String, AllowType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureServices = mapped
    }

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("usetxqmdqdhqpvbs")
    public fun azureServices(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureServices = mapped
    }

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("jiushqjyfqrrheqr")
    public fun azureServices(`value`: AllowType) {
        val toBeMapped = Either.ofRight<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureServices = mapped
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("lihosnuygughxebq")
    public suspend fun callerClientIP(`value`: Either<String, AllowType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.callerClientIP = mapped
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("cvusbcpckgxldpyv")
    public fun callerClientIP(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.callerClientIP = mapped
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("jlndahpkkswbpdmg")
    public fun callerClientIP(`value`: AllowType) {
        val toBeMapped = Either.ofRight<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.callerClientIP = mapped
    }

    /**
     * @param value This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("wiymwdwrwevvhhfh")
    public suspend fun ipRanges(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipRanges = mapped
    }

    /**
     * @param values This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("gjhtjmpqduvppilg")
    public suspend fun ipRanges(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRanges = mapped
    }

    internal fun build(): FirewallRulesArgs = FirewallRulesArgs(
        azureServices = azureServices,
        callerClientIP = callerClientIP,
        ipRanges = ipRanges,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/FirewallRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs.builder
import com.pulumi.azurenative.servicelinker.kotlin.enums.AllowType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Target service's firewall rules. to allow connections from source service.
 * @property azureServices Allow Azure services to access the target service if true.
 * @property callerClientIP Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
 * @property ipRanges This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
 */
public data class FirewallRulesArgs(
    public val azureServices: Output<Either<String, AllowType>>? = null,
    public val callerClientIP: Output<Either<String, AllowType>>? = null,
    public val ipRanges: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs =
        com.pulumi.azurenative.servicelinker.inputs.FirewallRulesArgs.builder()
            .azureServices(
                azureServices?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .callerClientIP(
                callerClientIP?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipRanges(ipRanges?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FirewallRulesArgs].
 */
@PulumiTagMarker
public class FirewallRulesArgsBuilder internal constructor() {
    private var azureServices: Output<Either<String, AllowType>>? = null

    private var callerClientIP: Output<Either<String, AllowType>>? = null

    private var ipRanges: Output<List<String>>? = null

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("erjtqggxfouljkpf")
    public suspend fun azureServices(`value`: Output<Either<String, AllowType>>) {
        this.azureServices = value
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("sphyrsqkxllgoeym")
    public suspend fun callerClientIP(`value`: Output<Either<String, AllowType>>) {
        this.callerClientIP = value
    }

    /**
     * @param value This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("cqhxdogwqrnwqxxj")
    public suspend fun ipRanges(`value`: Output<List<String>>) {
        this.ipRanges = value
    }

    @JvmName("pevubbxwvftpppmr")
    public suspend fun ipRanges(vararg values: Output<String>) {
        this.ipRanges = Output.all(values.asList())
    }

    /**
     * @param values This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("fmfvolavxcmmoaop")
    public suspend fun ipRanges(values: List<Output<String>>) {
        this.ipRanges = Output.all(values)
    }

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("nxmmlsklvbwobplx")
    public suspend fun azureServices(`value`: Either<String, AllowType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureServices = mapped
    }

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("tsqyswpiapybpocu")
    public fun azureServices(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureServices = mapped
    }

    /**
     * @param value Allow Azure services to access the target service if true.
     */
    @JvmName("uhritlfaoikqqipw")
    public fun azureServices(`value`: AllowType) {
        val toBeMapped = Either.ofRight<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureServices = mapped
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("jhvficdvxxpoljuq")
    public suspend fun callerClientIP(`value`: Either<String, AllowType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.callerClientIP = mapped
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("asvclrsbjwpfhquu")
    public fun callerClientIP(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.callerClientIP = mapped
    }

    /**
     * @param value Allow caller client IP to access the target service if true. the property is used when connecting local application to target service.
     */
    @JvmName("rponhgsqmmvrpnkv")
    public fun callerClientIP(`value`: AllowType) {
        val toBeMapped = Either.ofRight<String, AllowType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.callerClientIP = mapped
    }

    /**
     * @param value This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("lltimycxqvawseea")
    public suspend fun ipRanges(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipRanges = mapped
    }

    /**
     * @param values This value specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account.
     */
    @JvmName("cwqhambajgxrwaad")
    public suspend fun ipRanges(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRanges = mapped
    }

    internal fun build(): FirewallRulesArgs = FirewallRulesArgs(
        azureServices = azureServices,
        callerClientIP = callerClientIP,
        ipRanges = ipRanges,
    )
}
